==> guikachu-1.1.4.tar.gz: guikachu-1.1.4/src/blob-res.cc <==
//$Id: blob-res.cc,v 1.7 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "blob-res.h"
#include "blob-win.h"

using namespace Guikachu;
using std::string;
using std::ostream;

Resources::Blob::Blob (const string &id):
    Resource (id),
    gui (0),
    contents (changed, "")
{
}

Resources::Blob::~Blob ()
{
    delete gui;
}

void Resources::Blob::show_ui ()
{
    if (!gui)
	gui = new GUI::BlobWindow (this);

    gui->show ();
}

bool Resources::Blob::load (StorageNode &node)
{
    StorageNode curr_node;
    
    contents = node.get_content ();

    changed ();
    
    return true;
}

void Resources::Blob::save (StorageNode &node) const
{
    node.set_content (contents);
}

void Resources::Blob::save_rcp (ostream &ostr) const
{
    ostr << "/* Contents of blob '" << id << "' */" << std::endl;
    ostr << contents << std::endl << std::endl;
}

==> guikachu-1.2.1.tar.gz: guikachu-1.2.1/src/blob-res.cc <==
//$Id: blob-res.cc,v 1.8 2002/05/12 13:07:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "blob-res.h"
#include "blob-win.h"

using namespace Guikachu;
using std::string;
using std::ostream;

Resources::Blob::Blob (const string &id):
    Resource (id),
    gui (0),
    contents (changed, "")
{
}

Resources::Blob::~Blob ()
{
    delete gui;
}

void Resources::Blob::show_ui ()
{
    if (!gui)
	gui = new GUI::BlobWindow (this);

    gui->show ();
}

bool Resources::Blob::load (StorageNode &node)
{
    StorageNode curr_node;
    
    contents = node.get_content ();

    changed ();
    
    return true;
}

void Resources::Blob::save (StorageNode &node) const
{
    node.set_content (contents);
}

void Resources::Blob::save_rcp (ostream &ostr) const
{
    // We use contents.get_val() instead of contents to avoid the
    // escaping of quote marks
    
    ostr << "/* Contents of blob '" << id << "' */" << std::endl;
    ostr << contents.get_val () << std::endl << std::endl;
}
